bayespy.inference.vmp.nodes.gaussian.GaussianWishartMoments.add_converter
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartMoments.add_converter